@@ -1,10 +1,9 @@
 /*
-   SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
-#ifndef IMPORTWIZARD_H
-#define IMPORTWIZARD_H
+#pragma once
 
 #include "abstractimporter.h"
 
@@ -108,4 +107,3 @@ private:
     LibImportWizard::AbstractDisplayInfo *mAbstractDisplayInfo = nullptr;
 };
 
-#endif /* IMPORTWIZARD_H */
